@@ -8,7 +8,7 @@
 
 
 # define the SpecC system home directory
-export SPECC; SPECC=/home/pramodc/work/scc/scrc_dist/installed
+export SPECC; SPECC=/home/specc/scrc/current//installed
 
 # extend the search path
 export PATH; PATH=$PATH:$SPECC/bin
